
package Google::Ads::AdWords::v201209::TypeMaps::UserListService;
use strict;
use warnings;

our $typemap_1 = {
               'mutateResponse/rval/value[LogicalUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList' => 'Google::Ads::AdWords::v201209::UserList',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates' => 'Google::Ads::AdWords::v201209::Predicate',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201209::NotEmptyError::Reason',
               'mutateResponse/rval/value/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutateResponse/rval/value[RemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands' => 'Google::Ads::AdWords::v201209::LogicalUserListOperand',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201209::UserListConversionType::Category',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201209::RateExceededError::Reason',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'getResponse/rval/entries[RemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201209::AuthorizationError::Reason',
               'mutate/operations/operand/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/paging' => 'Google::Ads::AdWords::v201209::Paging',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[UserListError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201209::UserListConversionType::Category',
               'mutate/operations/operand[LogicalUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/operator' => 'Google::Ads::AdWords::v201209::UserListLogicalRule::Operator',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201209::UserList',
               'mutateResponse/rval/value/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutate/operations/operand[RemarketingUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[RemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules' => 'Google::Ads::AdWords::v201209::UserListLogicalRule',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList' => 'Google::Ads::AdWords::v201209::UserList',
               'mutateResponse/rval/value/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[RemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'get/serviceSelector/predicates/operator' => 'Google::Ads::AdWords::v201209::Predicate::Operator',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[RemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules' => 'Google::Ads::AdWords::v201209::UserListLogicalRule',
               'mutateResponse/rval/value/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[UserListError]/reason' => 'Google::Ads::AdWords::v201209::UserListError::Reason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201209::OperationAccessDenied',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[RemarketingUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserInterest/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201209::RateExceededError',
               'getResponse/rval/entries[LogicalUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutate/operations/operand/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands' => 'Google::Ads::AdWords::v201209::LogicalUserListOperand',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserInterest/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules' => 'Google::Ads::AdWords::v201209::UserListLogicalRule',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[RemarketingUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201209::QuotaCheckError::Reason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201209::DatabaseError::Reason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands' => 'Google::Ads::AdWords::v201209::LogicalUserListOperand',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201209::ClientTermsError::Reason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201209::InternalApiError',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes' => 'Google::Ads::AdWords::v201209::UserListConversionType',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[UserListError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[RemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserInterest' => 'Google::Ads::AdWords::v201209::UserInterest',
               'getResponse/rval/entries[LogicalUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutate/operations/operand[RemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'getResponse' => 'Google::Ads::AdWords::v201209::UserListService::getResponse',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]' => 'Google::Ads::AdWords::v201209::RemarketingUserList',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList' => 'Google::Ads::AdWords::v201209::UserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules' => 'Google::Ads::AdWords::v201209::UserListLogicalRule',
               'mutate/operations/operand[LogicalUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[RemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval' => 'Google::Ads::AdWords::v201209::UserListPage',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201209::ExternalRemarketingUserList',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201209::ClientTermsError',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserInterest/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201209::ExternalRemarketingUserList',
               'getResponse/rval/entries[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutate/operations/operand[RemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'getResponse/rval/entries/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList' => 'Google::Ads::AdWords::v201209::UserList',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201209::InternalApiError::Reason',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[RemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutateResponse/rval/value[LogicalUserList]' => 'Google::Ads::AdWords::v201209::LogicalUserList',
               'mutate/operations/operand[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[RemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201209::SelectorError::Reason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201209::DatabaseError',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201209::AuthorizationError',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutateResponse/rval/value/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[RemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutateResponse/rval/value/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201209::Operator',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201209::ExternalRemarketingUserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserInterest/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201209::UserListConversionType::Category',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201209::SizeLimitError',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[RemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201209::ExternalRemarketingUserList',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserInterest/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand[RemarketingUserList]' => 'Google::Ads::AdWords::v201209::RemarketingUserList',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]' => 'Google::Ads::AdWords::v201209::RemarketingUserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserInterest/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutate/operations/operand/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'getResponse/rval/entries[RemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserInterest' => 'Google::Ads::AdWords::v201209::UserInterest',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201209::UserListConversionType::Category',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[RemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/operator' => 'Google::Ads::AdWords::v201209::UserListLogicalRule::Operator',
               'mutate/operations/operand[ExternalRemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutateResponse/rval/value[RemarketingUserList]/conversionTypes' => 'Google::Ads::AdWords::v201209::UserListConversionType',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201209::ApiException',
               'getResponse/rval/entries[LogicalUserList]' => 'Google::Ads::AdWords::v201209::LogicalUserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201209::RangeError::Reason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'getResponse/rval/entries/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201209::ReadOnlyError',
               'mutateResponse/rval/value[LogicalUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutate/operations/operand[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201209::RequestError',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[RemarketingUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201209::RequiredError',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserInterest' => 'Google::Ads::AdWords::v201209::UserInterest',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'get/serviceSelector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]' => 'Google::Ads::AdWords::v201209::LogicalUserList',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201209::AuthenticationError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201209::NotEmptyError',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201209::UserListConversionType::Category',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutate/operations/operand[LogicalUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutate/operations/operand[LogicalUserList]/rules/operator' => 'Google::Ads::AdWords::v201209::UserListLogicalRule::Operator',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]' => 'Google::Ads::AdWords::v201209::LogicalUserList',
               'getResponse/rval/entries[LogicalUserList]/rules' => 'Google::Ads::AdWords::v201209::UserListLogicalRule',
               'getResponse/rval/entries[RemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'getResponse/rval/entries/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'getResponse/rval/entries[RemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes' => 'Google::Ads::AdWords::v201209::UserListConversionType',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201209::AuthenticationError::Reason',
               'mutate/operations/operand[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[RemarketingUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201209::UserListConversionType::Category',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands' => 'Google::Ads::AdWords::v201209::LogicalUserListOperand',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutateResponse' => 'Google::Ads::AdWords::v201209::UserListService::mutateResponse',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'getResponse/rval/entries[ExternalRemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'getResponse/rval/entries[LogicalUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/operator' => 'Google::Ads::AdWords::v201209::UserListLogicalRule::Operator',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'getResponse/rval/entries[RemarketingUserList]' => 'Google::Ads::AdWords::v201209::RemarketingUserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserInterest/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[ExternalRemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[RemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserInterest/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutate/operations/operand[RemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutateResponse/rval/value[RemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'getResponse/rval/entries[LogicalUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutateResponse/rval/value[RemarketingUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201209::UserListConversionType::Category',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserInterest/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'get/serviceSelector/dateRange' => 'Google::Ads::AdWords::v201209::DateRange',
               'get/serviceSelector/ordering/sortOrder' => 'Google::Ads::AdWords::v201209::SortOrder',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'get' => 'Google::Ads::AdWords::v201209::UserListService::get',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/operator' => 'Google::Ads::AdWords::v201209::UserListLogicalRule::Operator',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[RemarketingUserList]' => 'Google::Ads::AdWords::v201209::RemarketingUserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201209::ExternalRemarketingUserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserInterest/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutateResponse/rval/value/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserInterest/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201209::QuotaCheckError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[RemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201209::UserListConversionType::Category',
               'mutateResponse/rval/value[RemarketingUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutate/operations/operand[RemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'get/serviceSelector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[RemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserInterest/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]' => 'Google::Ads::AdWords::v201209::RemarketingUserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList' => 'Google::Ads::AdWords::v201209::UserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserInterest' => 'Google::Ads::AdWords::v201209::UserInterest',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'getResponse/rval/entries/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201209::DistinctError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands' => 'Google::Ads::AdWords::v201209::LogicalUserListOperand',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201209::NotWhitelistedError::Reason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutateResponse/rval/value[RemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutateResponse/rval/value[LogicalUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserInterest/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserInterest' => 'Google::Ads::AdWords::v201209::UserInterest',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'getResponse/rval/entries[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201209::ExternalRemarketingUserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserInterest/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserInterest/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserInterest/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutateResponse/rval/value[RemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'getResponse/rval/entries[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]' => 'Google::Ads::AdWords::v201209::LogicalUserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201209::ExternalRemarketingUserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserInterest/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes' => 'Google::Ads::AdWords::v201209::UserListConversionType',
               'mutate/operations/operand[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'getResponse/rval/entries[RemarketingUserList]/conversionTypes/category' => 'Google::Ads::AdWords::v201209::UserListConversionType::Category',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutateResponse/rval/value[RemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201209::RangeError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutate/operations/operand[RemarketingUserList]/conversionTypes/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/ordering' => 'Google::Ads::AdWords::v201209::OrderBy',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201209::NotWhitelistedError',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]' => 'Google::Ads::AdWords::v201209::LogicalUserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'getResponse/rval/entries[LogicalUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201209::RequiredError::Reason',
               'Fault/detail/ApiExceptionFault/errors[UserListError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'get/serviceSelector/ordering/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/fields' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201209::ReadOnlyError::Reason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserInterest' => 'Google::Ads::AdWords::v201209::UserInterest',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList' => 'Google::Ads::AdWords::v201209::UserList',
               'getResponse/rval/entries/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutateResponse/rval/value[RemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201209::ApiError',
               'getResponse/rval/entries[RemarketingUserList]/conversionTypes' => 'Google::Ads::AdWords::v201209::UserListConversionType',
               'mutate/operations/operand[RemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[ExternalRemarketingUserList]/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[RemarketingUserList]/sizeRange' => 'Google::Ads::AdWords::v201209::SizeRange',
               'mutate' => 'Google::Ads::AdWords::v201209::UserListService::mutate',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[UserListError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201209::ApiError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accessReason' => 'Google::Ads::AdWords::v201209::AccessReason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201209::ApiException',
               'getResponse/rval/entries/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]' => 'Google::Ads::AdWords::v201209::RemarketingUserList',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201209::SizeLimitError::Reason',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules' => 'Google::Ads::AdWords::v201209::UserListLogicalRule',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands' => 'Google::Ads::AdWords::v201209::LogicalUserListOperand',
               'mutateResponse/rval/value[RemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[RemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes' => 'Google::Ads::AdWords::v201209::UserListConversionType',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]' => 'Google::Ads::AdWords::v201209::RemarketingUserList',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201209::DistinctError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201209::RequestError::Reason',
               'mutateResponse/rval/value/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[RemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[ExternalRemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes' => 'Google::Ads::AdWords::v201209::UserListConversionType',
               'getResponse/rval/entries[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserInterest/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList/membershipLifeSpan' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[RemarketingUserList]/conversionTypes' => 'Google::Ads::AdWords::v201209::UserListConversionType',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/conversionTypes' => 'Google::Ads::AdWords::v201209::UserListConversionType',
               'get/serviceSelector/predicates/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[UserListError]' => 'Google::Ads::AdWords::v201209::UserListError',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/operator' => 'Google::Ads::AdWords::v201209::UserListLogicalRule::Operator',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201209::ExternalRemarketingUserList',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201209::UserListReturnValue',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201209::OperationAccessDenied::Reason',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/type' => 'Google::Ads::AdWords::v201209::UserList::Type',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[RemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201209::UserList',
               'mutateResponse/rval/value[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/UserList.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand[ExternalRemarketingUserList]' => 'Google::Ads::AdWords::v201209::ExternalRemarketingUserList',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value[RemarketingUserList]/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[RemarketingUserList]/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/size' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector' => 'Google::Ads::AdWords::v201209::Selector',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201209::UserList',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList/description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[LogicalUserList]/rules/ruleOperands/UserList[ExternalRemarketingUserList]/accountUserListStatus' => 'Google::Ads::AdWords::v201209::AccountUserListStatus',
               'mutate/operations/operand/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries[RemarketingUserList]/isReadOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]' => 'Google::Ads::AdWords::v201209::RemarketingUserList',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201209::SelectorError',
               'mutate/operations' => 'Google::Ads::AdWords::v201209::UserListOperation',
               'mutate/operations/operand[LogicalUserList]/rules/ruleOperands/UserList[RemarketingUserList]/status' => 'Google::Ads::AdWords::v201209::UserListMembershipStatus'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201209::TypeMaps::UserListService - typemap for UserListService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

