
package Google::Ads::AdWords::v201306::TypeMaps::AdExtensionOverrideService;
use strict;
use warnings;

our $typemap_1 = {
               'mutateResponse/rval/value/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201306::EntityNotFound::Reason',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors' => 'Google::Ads::AdWords::v201306::ApiError',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]' => 'Google::Ads::AdWords::v201306::ReadOnlyError',
               'mutateResponse/rval/value/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/averageCpm' => 'Google::Ads::AdWords::v201306::Money',
               'getResponse/rval/entries/stats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]' => 'Google::Ads::AdWords::v201306::AdxError',
               'getResponse/rval/entries/stats/cost' => 'Google::Ads::AdWords::v201306::Money',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201306::NotEmptyError::Reason',
               'mutateResponse/rval/value/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/overrideInfo' => 'Google::Ads::AdWords::v201306::OverrideInfo',
               'getResponse/rval/entries/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/reason' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideError::Reason',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201306::RateExceededError::Reason',
               'mutate/operations/operand/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201306::Sitelink',
               'getResponse/rval/entries/adExtension' => 'Google::Ads::AdWords::v201306::AdExtension',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201306::AuthorizationError::Reason',
               'mutate/operations/operand/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201306::SitelinksExtension',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201306::AdExtensionOverride',
               'mutateResponse/rval/value/status' => 'Google::Ads::AdWords::v201306::AdExtensionOverride::Status',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]' => 'Google::Ads::AdWords::v201306::EntityNotFound',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]' => 'Google::Ads::AdWords::v201306::ClientTermsError',
               'mutateResponse/rval/value/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201306::DomainInfoExtension',
               'mutate/operations/operand/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/network' => 'Google::Ads::AdWords::v201306::Stats::Network',
               'get/selector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdExtensionOverrideError]/reason' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideError::Reason',
               'mutateResponse/rval/value/stats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/shouldSyncUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/totalBudget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201306::GeoPoint',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201306::OAuthInfo',
               'getResponse/rval/entries/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201306::RateExceededError',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/reason' => 'Google::Ads::AdWords::v201306::RequiredError::Reason',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/averageCpm' => 'Google::Ads::AdWords::v201306::Money',
               'mutateResponse/rval/value/stats' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideStats',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201306::StringLengthError::Reason',
               'mutate/operations/operand/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201306::LocationOverrideInfo::RadiusUnits',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201306::Address',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201306::MobileExtension',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideStats',
               'getResponse/rval/entries/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201306::SitelinksExtension',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201306::InternalApiError::Reason',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201306::QuotaCheckError::Reason',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201306::DatabaseError::Reason',
               'mutate/operations/operand/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]' => 'Google::Ads::AdWords::v201306::SizeLimitError',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201306::ClientTermsError::Reason',
               'mutateResponse/rval/partialFailureErrors[NullError]/reason' => 'Google::Ads::AdWords::v201306::NullError::Reason',
               'mutate/operations/operand/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201306::InternalApiError',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/approvalStatus' => 'Google::Ads::AdWords::v201306::AdExtensionOverride::ApprovalStatus',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201306::InAppLinkExtension::AppStore',
               'getResponse' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideService::getResponse',
               'getResponse/rval/entries/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/reason' => 'Google::Ads::AdWords::v201306::DistinctError::Reason',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval' => 'Google::Ads::AdWords::v201306::AdExtensionOverridePage',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201306::ClientTermsError',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201306::DomainInfoExtension',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/reason' => 'Google::Ads::AdWords::v201306::OperatorError::Reason',
               'mutateResponse/rval/value/stats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/adIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/averageCpc' => 'Google::Ads::AdWords::v201306::Money',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201306::Address',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201306::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]' => 'Google::Ads::AdWords::v201306::RequiredError',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]' => 'Google::Ads::AdWords::v201306::RateExceededError',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/totalBudget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201306::InternalApiError::Reason',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/network' => 'Google::Ads::AdWords::v201306::Stats::Network',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201306::Sitelink',
               'getResponse/rval/entries/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201306::LocationOverrideInfo::RadiusUnits',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201306::DatabaseError',
               'mutate/operations/operand/stats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201306::AuthorizationError',
               'mutateResponse/rval/value/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'getResponse/rval/entries/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/provinceCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/imageMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/paging' => 'Google::Ads::AdWords::v201306::Paging',
               'mutateResponse/rval/partialFailureErrors[RequestError]/reason' => 'Google::Ads::AdWords::v201306::RequestError::Reason',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201306::LocationSyncExtension',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/statuses' => 'Google::Ads::AdWords::v201306::AdExtensionOverride::Status',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201306::Operator',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201306::InAppLinkExtension::AppStore',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]/reason' => 'Google::Ads::AdWords::v201306::AdxError::Reason',
               'mutateResponse/rval/value/adExtension[LocationExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/totalBudget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201306::SizeLimitError',
               'mutateResponse/rval/value/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension' => 'Google::Ads::AdWords::v201306::AdExtension',
               'getResponse/rval/entries/stats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]' => 'Google::Ads::AdWords::v201306::NotEmptyError',
               'mutateResponse/rval/partialFailureErrors[RequestError]' => 'Google::Ads::AdWords::v201306::RequestError',
               'mutateResponse/rval/value/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'mutateResponse/rval/partialFailureErrors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]' => 'Google::Ads::AdWords::v201306::AuthorizationError',
               'mutateResponse/rval/partialFailureErrors[AdExtensionOverrideError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/status' => 'Google::Ads::AdWords::v201306::AdExtensionOverride::Status',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RangeError]/reason' => 'Google::Ads::AdWords::v201306::RangeError::Reason',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201306::ReadOnlyError::Reason',
               'mutate/operations/operand/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201306::LocationExtension',
               'getResponse/rval/entries/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201306::LocationExtension',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201306::NotWhitelistedError::Reason',
               'mutateResponse/rval/value/stats/averageCpc' => 'Google::Ads::AdWords::v201306::Money',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension' => 'Google::Ads::AdWords::v201306::AdExtension',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/averageCpm' => 'Google::Ads::AdWords::v201306::Money',
               'mutate/operations/operand/stats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201306::LocationSyncExtension',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'mutate/operations/operand/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201306::LocationOverrideInfo',
               'mutate/operations/operand/adExtension[LocationExtension]/geoPoint/latitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201306::InAppLinkExtension',
               'mutateResponse/rval/value/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NullError]' => 'Google::Ads::AdWords::v201306::NullError',
               'mutateResponse/rval/value/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201306::LocationExtension::Source',
               'mutate/operations/operand/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]' => 'Google::Ads::AdWords::v201306::StringLengthError',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201306::OAuthInfo',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201306::ApiException',
               'mutateResponse/rval/partialFailureErrors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdExtensionOverrideError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[SitelinksExtension]/sitelinks' => 'Google::Ads::AdWords::v201306::Sitelink',
               'mutateResponse/rval/value/approvalStatus' => 'Google::Ads::AdWords::v201306::AdExtensionOverride::ApprovalStatus',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201306::RangeError::Reason',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201306::ReadOnlyError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201306::RequestError',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201306::RequiredError',
               'mutate/operations/operand/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/overrideInfo' => 'Google::Ads::AdWords::v201306::OverrideInfo',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201306::AuthenticationError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201306::NotEmptyError',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/averageCpc' => 'Google::Ads::AdWords::v201306::Money',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideSelector',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/oAuthInfo' => 'Google::Ads::AdWords::v201306::OAuthInfo',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201306::AuthenticationError::Reason',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/cost' => 'Google::Ads::AdWords::v201306::Money',
               'mutateResponse/rval/partialFailureErrors[RangeError]' => 'Google::Ads::AdWords::v201306::RangeError',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]/reason' => 'Google::Ads::AdWords::v201306::IdError::Reason',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201306::StringLengthError::Reason',
               'mutateResponse/rval/value/stats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideService::mutateResponse',
               'Fault/detail/ApiExceptionFault/errors[AdxError]' => 'Google::Ads::AdWords::v201306::AdxError',
               'getResponse/rval/entries/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201306::DatabaseError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201306::LocationExtension::Source',
               'Fault/detail/ApiExceptionFault/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201306::OperatorError::Reason',
               'mutateResponse/rval/partialFailureErrors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/oAuthInfo/httpRequestUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/totalBudget' => 'Google::Ads::AdWords::v201306::Money',
               'mutateResponse/rval/partialFailureErrors[AdExtensionOverrideError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/stats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201306::GeoPoint',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]' => 'Google::Ads::AdWords::v201306::IdError',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address' => 'Google::Ads::AdWords::v201306::Address',
               'get' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideService::get',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'mutate/operations/operand/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/totalBudget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/cost' => 'Google::Ads::AdWords::v201306::Money',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201306::QuotaCheckError',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201306::MobileExtension',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/oAuthInfo/httpMethod' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[SitelinksExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/overrideInfo/LocationOverrideInfo/radiusUnits' => 'Google::Ads::AdWords::v201306::LocationOverrideInfo::RadiusUnits',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/oAuthInfo/httpAuthorizationHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[InAppLinkExtension]/appStore' => 'Google::Ads::AdWords::v201306::InAppLinkExtension::AppStore',
               'get/selector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201306::SizeLimitError::Reason',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdxError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/companyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201306::StringLengthError',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201306::AuthenticationError::Reason',
               'mutate/operations/operand/adExtension[MobileExtension]/isCallOnly' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201306::EntityNotFound',
               'mutateResponse/rval/partialFailureErrors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/iconMediaId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/status' => 'Google::Ads::AdWords::v201306::AdExtensionOverride::Status',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201306::EntityNotFound::Reason',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201306::DistinctError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]' => 'Google::Ads::AdWords::v201306::QuotaCheckError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[DomainInfoExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201306::NotWhitelistedError::Reason',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/provinceName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201306::LocationOverrideInfo',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/totalBudget/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/source' => 'Google::Ads::AdWords::v201306::LocationExtension::Source',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201306::NullError',
               'getResponse/rval/entries/adExtension[DomainInfoExtension]' => 'Google::Ads::AdWords::v201306::DomainInfoExtension',
               'mutateResponse/rval/partialFailureErrors[AdxError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/campaignIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/adExtension[LocationExtension]/address/streetAddress' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/overrideInfo/LocationOverrideInfo' => 'Google::Ads::AdWords::v201306::LocationOverrideInfo',
               'getResponse/rval/entries/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/totalBudget/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/totalBudget' => 'Google::Ads::AdWords::v201306::Money',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]' => 'Google::Ads::AdWords::v201306::AuthenticationError',
               'mutateResponse/rval/partialFailureErrors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201306::NotEmptyError::Reason',
               'mutateResponse/rval/partialFailureErrors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[InAppLinkExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/geoPoint' => 'Google::Ads::AdWords::v201306::GeoPoint',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/address/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[SitelinksExtension]/sitelinks/destinationUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201306::QuotaCheckError::Reason',
               'getResponse/rval/entries/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201306::RangeError',
               'mutate/operations/operand/stats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/partialFailureErrors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/overrideInfo/LocationOverrideInfo/radius' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationExtension]/encodedLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::base64Binary',
               'mutateResponse/rval/value/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/stats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[LocationExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[MobileExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[OperatorError]' => 'Google::Ads::AdWords::v201306::OperatorError',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/streetAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201306::NotWhitelistedError',
               'mutateResponse/rval/value/adExtension[MobileExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[InAppLinkExtension]/inAppLinkUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201306::RequiredError::Reason',
               'mutate/operations/operand/stats' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideStats',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[DomainInfoExtension]/languageCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdxError]/reason' => 'Google::Ads::AdWords::v201306::AdxError::Reason',
               'getResponse/rval/entries/stats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[DomainInfoExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adExtension[MobileExtension]' => 'Google::Ads::AdWords::v201306::MobileExtension',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201306::ReadOnlyError::Reason',
               'mutateResponse/rval/partialFailureErrors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationSyncExtension]' => 'Google::Ads::AdWords::v201306::LocationSyncExtension',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201306::NullError::Reason',
               'mutateResponse/rval/partialFailureErrors[AdxError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/reason' => 'Google::Ads::AdWords::v201306::IdError::Reason',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/totalBudget' => 'Google::Ads::AdWords::v201306::Money',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201306::ApiError',
               'mutate/operations/operand/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/adExtension[LocationExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[LocationExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideService::mutate',
               'mutateResponse/rval/value/adExtension[LocationExtension]' => 'Google::Ads::AdWords::v201306::LocationExtension',
               'mutateResponse/rval/partialFailureErrors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201306::InAppLinkExtension',
               'mutateResponse/rval/value/adExtension[LocationExtension]/geoPoint/longitudeInMicroDegrees' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201306::ApiError',
               'mutate/operations/operand/stats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[InAppLinkExtension]' => 'Google::Ads::AdWords::v201306::InAppLinkExtension',
               'mutateResponse/rval/value/adExtension[InAppLinkExtension]/appId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201306::RateExceededError::Reason',
               'getResponse/rval/entries/adExtension[MobileExtension]/phoneNumber' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201306::ApiException',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[SitelinksExtension]/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201306::SizeLimitError::Reason',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdExtensionOverrideError]' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideError',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[InAppLinkExtension]/inAppLinkText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/postalCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/network' => 'Google::Ads::AdWords::v201306::Stats::Network',
               'mutateResponse/rval/partialFailureErrors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201306::NotWhitelistedError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201306::RequestError::Reason',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201306::DistinctError',
               'mutateResponse/rval/partialFailureErrors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/adExtension[SitelinksExtension]/sitelinks/displayText' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[DomainInfoExtension]/domainName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[InternalApiError]' => 'Google::Ads::AdWords::v201306::InternalApiError',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]' => 'Google::Ads::AdWords::v201306::IdError',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[InAppLinkExtension]/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/approvalStatus' => 'Google::Ads::AdWords::v201306::AdExtensionOverride::ApprovalStatus',
               'mutate/operations/operand/stats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideReturnValue',
               'mutateResponse/rval/partialFailureErrors[AdExtensionOverrideError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/overrideInfo' => 'Google::Ads::AdWords::v201306::OverrideInfo',
               'mutateResponse/rval/partialFailureErrors[DatabaseError]' => 'Google::Ads::AdWords::v201306::DatabaseError',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[AdExtensionOverrideError]' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideError',
               'get/selector/adExtensionIds' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[SitelinksExtension]' => 'Google::Ads::AdWords::v201306::SitelinksExtension',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201306::AdExtensionOverride',
               'mutateResponse/rval/value/stats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/partialFailureErrors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/adExtension[MobileExtension]/isCallTrackingEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/adExtension[MobileExtension]/countryCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]' => 'Google::Ads::AdWords::v201306::OperatorError',
               'mutateResponse/rval/partialFailureErrors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201306::ClientTermsError::Reason',
               'getResponse/rval/entries/adExtension/AdExtension.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/adExtension[LocationExtension]/address/cityName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201306::AdExtensionOverride',
               'mutateResponse/rval/partialFailureErrors[AdxError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/partialFailureErrors[DistinctError]' => 'Google::Ads::AdWords::v201306::DistinctError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/adExtension[LocationSyncExtension]/authToken' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations' => 'Google::Ads::AdWords::v201306::AdExtensionOverrideOperation'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201306::TypeMaps::AdExtensionOverrideService - typemap for AdExtensionOverrideService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

